@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KITINERARY_GENERATOR_TRAINSTATIONDBGENERATOR_H
-#define KITINERARY_GENERATOR_TRAINSTATIONDBGENERATOR_H
+#pragma once
 
 #include <knowledgedb.h>
 #include <stationidentifier.h>
@@ -75,4 +74,3 @@ private:
 }
 }
 
-#endif // KITINERARY_GENERATOR_TRAINSTATIONDBGENERATOR_H
