@@ -11,7 +11,7 @@
 #include "flightpostprocessor_p.h"
 
 #include "extractorutil.h"
-#include "iatabcbpparser.h"
+#include "iata/iatabcbpparser.h"
 #include "jsonlddocument.h"
 #include "logging.h"
 #include "mergeutil.h"
@@ -382,6 +382,8 @@ EventReservation ExtractorPostprocessorPrivate::processEventReservation(EventRes
 
 Event ExtractorPostprocessorPrivate::processEvent(Event event) const
 {
+    event.setName(event.name().trimmed());
+
     // normalize location to be a Place
     if (JsonLd::isA<PostalAddress>(event.location())) {
         Place place;
@@ -406,6 +408,7 @@ T ExtractorPostprocessorPrivate::processReservation(T res) const
 {
     res.setUnderName(processPerson(res.underName().template value<Person>()));
     res.setPotentialAction(processActions(res.potentialAction()));
+    res.setReservationNumber(res.reservationNumber().trimmed());
     return res;
 }
 
