@@ -318,7 +318,8 @@ static bool isSameTrainTrip(const TrainTrip &lhs, const TrainTrip &rhs)
     // for unbound tickets, comparing the line number below wont help
     // so we have to use the slightly less robust location comparisson
     if (!lhs.departureTime().isValid() && !rhs.departureTime().isValid()) {
-        return lhs.departureStation().name() == rhs.departureStation().name() && lhs.arrivalStation().name() == rhs.departureStation().name();
+        qCDebug(CompareLog) << "unbound trip" << lhs.departureStation().name() << rhs.departureStation().name() << lhs.arrivalStation().name() << rhs.arrivalStation().name();
+        return lhs.departureStation().name() == rhs.departureStation().name() && lhs.arrivalStation().name() == rhs.arrivalStation().name();
     }
 
     if (lhs.trainNumber().isEmpty() || rhs.trainNumber().isEmpty()) {
